Learn R Programming

r4ss (version 1.20)

SS_makedatlist: make a list for SS data

Description

create a list similar to those built by SS_readdat which can be written to a Stock Synthesis data file using SS_writedat. In hindsight, this function doesn't seem very useful and I haven't taken time to describe the arguments below.

Usage

SS_makedatlist(styr = 1971, endyr = 2001, nseas = 1, months_per_seas =
12, spawn_seas = 1, Nfleet = 1, Nsurveys = 1, N_areas = 1, fleetnames =
c("fishery1", "survey1"), surveytiming = 0.5, areas = 1, units_of_catch
= 1, se_log_catch = 0.01, Ngenders = 2, Nages = 40, init_equil = 0,
catch = NULL, CPUE = NULL, N_discard_fleets = 0, discard_data = NULL,
meanbodywt = NULL, DF_for_meanbodywt = 30, lbin_method = 2,
binwidth = 2, minimum_size = 2,
maximum_size = 90, comp_tail_compression = -1e-04, add_to_comp = 1e-04,
max_combined_lbin = 0, lbin_vector = seq(22, 90, 2), lencomp = NULL,
agebin_vector = 1:25, ageerror = data.frame(rbind(0:40 + 0.5, 0.001,
0:40 + 0.5, seq(0.525, 2.525, 0.05))), agecomp = NULL, Lbin_method = 3,
max_combined_age = 1, MeanSize_at_Age_obs = NULL, N_environ_variables =
0, N_environ_obs = 0, N_sizefreq_methods = 0, do_tags = 0,
morphcomp_data = 0)

Arguments

styr
start year of the model
endyr
end year of the model
nseas
number of seasons
months_per_seas
months per seasons
spawn_seas
spawning season
Nfleet
number of fishing fleets
Nsurveys
number of surveys
N_areas
number of areas
fleetnames
names of fleets
surveytiming
vector of survey timings
areas
area definitions for each fleet or survey
units_of_catch
units of catch for each fleet
se_log_catch
Uncertainty in catch (standard error in log space).
Ngenders
Number of genders.
Nages
Number of ages.
init_equil
Initial equilibrium catch.
catch
Catch data
CPUE
Indices of abundance (if present).
N_discard_fleets
Number of fleets with discard data.
discard_data
Discard data (if exists).
meanbodywt
Mean body weight data (if exists)
DF_for_meanbodywt
Degrees of freedom for mean body weight t-distribution.
lbin_method
Method for entering length bins. (1=use databins; 2=generate from binwidth,min,max below; 3=read vector). Not sure if all options implemented.
binwidth
Bin width for length bins.
minimum_size
Lower bound of length bins.
maximum_size
Upper bound of length bins.
comp_tail_compression
Value below which tails of composition data will be compressed (negative to turn off).
add_to_comp
Robustifying constant added to multinomial composition likelihoods.
max_combined_lbin
Maximum length bin below which length composition data will have genders combined.
lbin_vector
Vector of length bins.
lencomp
Length composition data (if exists).
agebin_vector
Vector of age bins.
ageerror
Ageing error matrices.
agecomp
Age composition data (if exists).
Lbin_method
Method of specifying length bins in conditional age-at-length data.
max_combined_age
Maximum age below which age composition data will have genders combined.
MeanSize_at_Age_obs
Data on mean size at age (if exists).
N_environ_variables
Number of environmental variables.
N_environ_obs
Number of environmental observations.
N_sizefreq_methods
Number of size frequency methods.
do_tags
Include tag data? NOT IMPLEMENTED YET.
morphcomp_data
Morph composition data. NOT IMPLEMENTED YET.

See Also

SS_readdat, SS_writedat