Write Stock Synthesis data file from list object in R which was probably
created using SS_readdat (which would have called on
SS_readdat_3.30).
SS_writedat_3.30(datlist, outfile, overwrite = FALSE, faster = FALSE,
verbose = TRUE)List object created by SS_readdat.
Filename for where to write new data file.
Should existing files be overwritten? Default=FALSE.
Speed up writing by writing length and age comps without aligning the columns (by using write.table instead of print.data.frame)
Should there be verbose output while running the file?
SS_writedat, SS_writedat_3.24,
SS_readdat, SS_makedatlist,
SS_readstarter, SS_writestarter,
SS_readforecast, SS_writeforecast