Skip to contents

write Stock Synthesis forecast file from list object in R which was probably created using SS_readforecast()

Usage

SS_writeforecast(
  mylist,
  dir = getwd(),
  file = "forecast.ss",
  writeAll = FALSE,
  overwrite = FALSE,
  verbose = TRUE
)

Arguments

mylist

List object created by SS_readforecast().

dir

A file path to the directory of interest. When omitted, functions typically default to the current working directory or the model directory stored in replist.

file

Filename for new forecast file. Default="forecast.ss".

writeAll

Should the function continue even if Forecast=0 (at which point SS stops reading, and remaining elements in list may not be available, depending on settings used in SS_readforecast)

overwrite

A logical value specifying if the existing file(s) should be overwritten. The default value is overwrite = FALSE.

verbose

A logical value specifying if output should be printed to the screen.

Author

Ian G. Taylor, Kelli F. Johnson, Kathryn L. Doering, Nathan R. Vaughan