Skip to contents

write Stock Synthesis starter file from list object in R which was probably created using SS_readstarter()

Usage

SS_writestarter(
  mylist,
  dir = getwd(),
  file = "starter.ss",
  overwrite = FALSE,
  verbose = TRUE,
  warn = lifecycle::deprecated()
)

Arguments

mylist

List object created by SS_readstarter().

dir

A file path to the directory of interest. When omitted, functions typically default to the current working directory or the model directory stored in replist.

file

Filename for new starter file. Default="starter.ss".

overwrite

A logical value specifying if the existing file(s) should be overwritten. The default value is overwrite = FALSE.

verbose

A logical value specifying if output should be printed to the screen.

warn

Deprecated.

Author

Ian G. Taylor, Kelli F. Johnson, Kathryn R. Doering