Write Stock Synthesis weight-at-age file from R object that was probably
created using SS_readwtatage()
Usage
SS_writewtatage(
mylist,
dir = getwd(),
file = "wtatage.ss",
overwrite = FALSE,
verbose = TRUE,
warn = lifecycle::deprecated()
)Arguments
- mylist
Object created by
SS_readwtatage().- dir
A file path to the directory of interest. When omitted, functions typically default to the current working directory or the model directory stored in
replist.- file
Filename for new weight-at-age file, which will be appended to
dirto create a full file path. Default="wtatage.ss".- overwrite
A logical value specifying if the existing file(s) should be overwritten. The default value is
overwrite = FALSE.- verbose
A logical value specifying if output should be printed to the screen.
- warn
Deprecated.