Usage
SS_fitbiasramp(replist, verbose=FALSE, startvalues=NULL, method="BFGS",
twoplots=TRUE, transform=FALSE, plot=TRUE, print=FALSE,
plotdir="default", oldctl=NULL,
newctl=NULL, nlminb=TRUE, pwidth=7, pheight=7, punits="in",
ptsize=12, res=300, cex.main=1)
Arguments
verbose
Controls the amount of output to the screen.
Default=FALSE.
startvalues
A vector of 5 values for the starting points in
the minimization. Default=NULL.
method
A method to apply to the 'optim' function. See ?optim
for options. Default="BFGS".
twoplots
Make a two-panel plot showing devs as well as
transformed uncertainty, or just the second panel in the set?
Default=TRUE.
transform
An experimental option to treat the transform the 5
quantities to improve minimization. Doesn't work well. Default=FALSE.
plot
Plot to active plot device?
plotdir
Directory where PNG files will be written. By default
it will be the directory where the model was run.
oldctl
Optional name of existing control file to modify.
Default=NULL.
newctl
Optional name of new control file to create from old
file with estimated bias adjustment values. Default=NULL.
nlminb
Use the 'nlminb' function instead of 'optim'?
Default=TRUE
pwidth
Default width of plots printed to files in units of punits. Default=7.
pheight
Default height width of plots printed to files in units of punits. Default=7.
punits
Units for pwidth and pheight. Can be "px" (pixels), "in" (inches), "cm" or "mm". Default="in".
ptsize
Point size for plotted text in plots printed to files (see help("png") in R for details). Default=12.
res
Resolution of plots printed to files. Default=300.
cex.main
Character expansion for plot titles.