Learn R Programming

r4ss (version 1.03)

SS_fitbiasramp: Estimate bias adjustment for recruitment deviates

Description

Uses standard error of estimated recruitment deviates to estimate the 5 controls for the bias adjustment in Stock Synthesis

Usage

SS_fitbiasramp(replist,verbose=F,startvalues=NULL,method="Nelder-Mead",transform=F)

Arguments

replist
Object created using SSv3_output
verbose
Controls the amount of output to the screen. Default=F.
startvalues
A vector of 5 values for the starting points in the minimization. Default=NULL.
method
A method to apply to the 'optim' function. See ?optim for options. Default='Nelder-Mead'.
transform
An experimental option to treat the transform the 5 quantities to improve minimization. Doesn't work well. Default=F.

See Also

SSv3_output