Learn R Programming

r4ss (version 1.14)

SSplotData: Timeline of presence/absence of data by type, year, and fleet.

Description

Plot shows graphical display of what data is being used in the model. Some data types may not yet be included. Note, this is based on output from the model, not the input data file.

Usage

SSplotData(replist, fleetcol = "default", datatypes = "all", fleets =
"all", ghost = FALSE)

Arguments

replist
list created by SS_output
fleetcol
Either the string "default", or a vector of colors to use for each fleet.
datatypes
Either the string "all", or a vector including some subset of the following: "catch", "cpue", "lendbase", "sizedbase", "agedbase", "condbase", "ghostagedbase", "ghostcondbase", "ghostlendbase", "ladbase", "wadbase", "tagdbase1", "tagdbase2"
fleets
Either the string "all", or a vector of numerical values, like c(1,3), listing fleets or surveys to be included in the plot.
ghost
TRUE/FALSE indicator for whether to show presence of composition data from ghost fleets (data for which the fit is shown, but is not included in the likelihood calculations).

Value

    See Also

    SS_plots, SS_output, SS_readdat